-- Surface area
function Pa()
  return macalc.rcl(1)
end

function Pb()
  return macalc.rcl(2)
end

function Ph()
  return macalc.rcl(3)
end

function F()
  return Pb()-Ph()
end

function Fa()
  return sqrt(Pa()^2-(Pa()^2*F()^2/Pb()^2))
end

function Fb()
  return sqrt(Pb()^2-F()^2)
end

function r(x)
  return sqrt(Pb()^2-(x^2*Pb()^2/Pa()^2))
end

function arclength(r)
  if r > 0 then
    return r*(pi - 2*asin(F()/r))
  else
    return 0
  end
end

function tip()
  -- Set slices and iterator
  slices = 1000
  i = 1
  -- Set delta from ground intersect x-distance to tip of prolate
  d = (Pa()-Fa())/slices
  -- Set initial x-coordinate just below top
  x = Pa()-d
  -- Set total area to the dome area at end of prolate
  t = (d^2+r(x)^2)*pi

  repeat
    -- first x,y and circumference
    ax = Pa()-d*i
    ay = r(ax)
    ac = ay*2*pi
    -- second x,y and circumference
    bx = Pa()-d*(i+1)
    by = r(bx)
    bc = by*2*pi
    -- distance between slice edges
    dst = sqrt((ax-bx)^2+(ay-by)^2)

    -- trapezoid area
    area = dst*((ac+bc)/2)

    -- add up area and increment
    t = t + area
    i = i + 1

  until i>=slices

  return t*2
end

function body()
  -- Set slices and iterator
  slices = 5000
  i = 0
  t = 0
  -- Set delta from ground intersect to center
  d = Fa()/slices

  repeat
    -- first x,y and circumference
    ax = Fa()-d*i
    ay = r(ax)
    ac = arclength(ay)
    -- second x,y and circumference
    bx = Fa()-d*(i+1)
    by = r(bx)
    bc = arclength(by)
    -- distance between slice edges
    dst = sqrt((ax-bx)^2+(ay-by)^2)

    -- trapezoid area
    area = dst*((ac+bc)/2)

    -- add up area and increment
    t = t + area
    i = i + 1

  until i>=slices

  return t*2
end

function lua_main()
  if F()<=0 then
    return tip() + body()
  else
    return body()
  end
end
